Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Vault ¶
type Vault interface {
// GetSecret retrieves a secret from the vault by its name.
GetSecret(secretName string) (interface{}, error)
// PutSecret stores a secret in the vault under the given name.
PutSecret(secretName string, secretValue interface{}) error
// DeleteSecret deletes a secret from the vault by its name.
DeleteSecret(secretName string) error
// GetLocalSecret retrieves a locally stored secret by its name.
GetLocalSecret(secretName string) (interface{}, bool)
// PutLocalSecret stores a secret locally within the object.
PutLocalSecret(secretName string, secretValue interface{}) error
// DeleteLocalSecret deletes a locally stored secret by its name.
DeleteLocalSecret(secretName string) error
}
Vault represents an interface for secret management.
Click to show internal directories.
Click to hide internal directories.